==> eminem_lyric-1.0.1.tar.gz: eminem_lyric-1.0.1/README.md <==
# eminem_lyric

[![License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE)

## Overview
**eminem_lyric** is a Python package designed for all Eminem stans out there. I have been an Eminem stan since the early 2000s, so if you've been a fan of Eminem's music since "The Slim Shady LP" or if you've recently discovered his talent, this package is for you. With **eminem_lyric**, you can easily access the lyrics of your favorite Eminem tracks, from his early hits to his latest releases. 

## Features
- **Easy to Use**: Retrieve lyrics with just a few lines of Python code.
- **Comprehensive**: Access lyrics for a wide range of Eminem songs.
- **Flexible**: Retrieve lyrics as plain text or in raw JSON format.

## Installation
You can install the eminem_lyric package via pip:

```bash
pip install eminem_lyric
```

For more information and usage instructions, visit the [PyPI page](https://pypi.org/project/eminem_lyric/).

## Documentation
For more detailed documentation, including API references and usage examples, please visit the [documentation](./docs/index.md).

## Examples
Check out the [examples](./examples) directory for usage examples of the eminem_lyric package.

## Contributing
Contributions are welcome! Here are some ways you can contribute to the project:
- Report bugs and issues
- Suggest new features or improvements
- Submit pull requests with bug fixes or enhancements

## Author
- Emad &nbsp; E>
  
  [<img src="https://img.shields.io/badge/GitHub-Profile-blue?logo=github" width="150">](https://github.com/emads22)

## License
This project is licensed under the **MIT License**, which grants permission for free use, modification, distribution, and sublicense of the code, provided that the copyright notice (attributed to [emads22](https://github.com/emads22)) and permission notice are included in all copies or substantial portions of the software. This license is permissive and allows users to utilize the code for both commercial and non-commercial purposes.

Please see the [LICENSE](LICENSE) file for more details.

==> eminem_lyric-1.0.4.tar.gz: eminem_lyric-1.0.4/README.md <==
# eminem_lyric

[![License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE)

## Overview
**eminem_lyric** is a Python package designed for all Eminem stans out there. I have been an Eminem stan since the early 2000s, so if you've been a fan of Eminem's music since "The Slim Shady LP" or if you've recently discovered his talent, this package is for you. With **eminem_lyric**, you can easily access the lyrics of your favorite Eminem tracks, from his early hits to his latest releases. 

## Features
- **Easy to Use**: Retrieve lyrics with just a few lines of Python code.
- **Comprehensive**: Access lyrics for a wide range of Eminem songs.
- **Flexible**: Retrieve lyrics as plain text or in raw JSON format.

## Installation
You can install the eminem_lyric package via pip:

```bash
pip install eminem_lyric
```

For more information and usage instructions, visit the [PyPI page](https://pypi.org/project/eminem_lyric/).

## Documentation
For more detailed documentation, including API reference and usage examples, please visit the [documentation](https://github.com/emads22/eminem-lyric-package/tree/main/docs/index.md).

## Examples
Check out the [examples](https://github.com/emads22/eminem-lyric-package/tree/main/examples) directory for usage examples of the eminem_lyric package.

## Contributing
Contributions are welcome! Here are some ways you can contribute to the project:
- Report bugs and issues
- Suggest new features or improvements
- Submit pull requests with bug fixes or enhancements

## Author
- Emad &nbsp; E>
  
  [<img src="https://img.shields.io/badge/GitHub-Profile-blue?logo=github" width="150">](https://github.com/emads22)

## License
This project is licensed under the **MIT License**, which grants permission for free use, modification, distribution, and sublicense of the code, provided that the copyright notice (attributed to [emads22](https://github.com/emads22)) and permission notice are included in all copies or substantial portions of the software. This license is permissive and allows users to utilize the code for both commercial and non-commercial purposes.

Please see the [LICENSE](LICENSE) file for more details.
